summaryrefslogtreecommitdiff
path: root/src/irc/irc.h
diff options
context:
space:
mode:
authorSebastien Helleu <flashcode@flashtux.org>2004-07-01 20:43:57 +0000
committerSebastien Helleu <flashcode@flashtux.org>2004-07-01 20:43:57 +0000
commit062e5ea1aed8e37c717b15283adcba0e1a62c9b1 (patch)
tree32746e312f5b5816c9e89798df9c438416491a2b /src/irc/irc.h
parent66ff97166f17621d962f1254b09757af26ebc2c7 (diff)
downloadweechat-062e5ea1aed8e37c717b15283adcba0e1a62c9b1.zip
Window management
Diffstat (limited to 'src/irc/irc.h')
-rw-r--r--src/irc/irc.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/irc/irc.h b/src/irc/irc.h
index c34816a34..d194cfda7 100644
--- a/src/irc/irc.h
+++ b/src/irc/irc.h
@@ -83,7 +83,7 @@ struct t_irc_channel
char *key; /* channel key (NULL if no key is set) */
t_irc_nick *nicks; /* nicks on the channel */
t_irc_nick *last_nick; /* last nick on the channel */
- t_gui_view *view; /* GUI view allocated for channel */
+ t_gui_buffer *buffer; /* GUI buffer allocated for channel */
t_irc_channel *prev_channel; /* link to previous channel */
t_irc_channel *next_channel; /* link to next channel */
};
@@ -116,7 +116,7 @@ struct t_irc_server
int is_away; /* 1 is user is marker as away */
int server_read; /* pipe for reading server data */
int server_write; /* pipe for sending data to server */
- t_gui_view *view; /* GUI view allocated for server */
+ t_gui_buffer *buffer; /* GUI buffer allocated for server */
t_irc_channel *channels; /* opened channels on server */
t_irc_channel *last_channel; /* last opened channal on server */
t_irc_server *prev_server; /* link to previous server */
@@ -204,9 +204,9 @@ extern void dcc_send ();
/* IRC display (irc-diplay.c) */
-extern void irc_display_prefix (/*@null@*/ t_gui_view *, char *);
-extern void irc_display_nick (t_gui_view *, t_irc_nick *, int, int, int, int);
-extern void irc_display_mode (t_gui_view *, char *, char, char *, char *,
+extern void irc_display_prefix (/*@null@*/ t_gui_buffer *, char *);
+extern void irc_display_nick (t_gui_buffer *, t_irc_nick *, int, int, int, int);
+extern void irc_display_mode (t_gui_buffer *, char *, char, char *, char *,
char *, char *);
/* IRC protocol (irc-commands.c) */